.. :Wedge:

Wedge
==========

.. currentmodule:: Wedge



.. autosummary::
   :nosignatures:

    Wedge.Wedge
    Wedge.Wedge.__init__
    Wedge.Wedge.plot
    Wedge.Wedge.calculateDetectorAnalyserPositions
    
	


Wedge Object and Methods
-------------------------


.. automodule:: Wedge

.. _Wedge:

.. autoclass:: Wedge
    :members:

    .. automethod:: __init__


